tlslite.integration.xmlrpcserver

Package tlslite :: Package integration :: Module xmlrpcserver |
[hide private]
[frames] | no frames]

# Module xmlrpcserver

source code

xmlrpcserver.py - simple XML RPC server supporting TLS

Classes | [hide private]
| MultiPathTLSXMLRPCServer Multipath XML-RPC Server using TLS
| TLSXMLRPCRequestHandler XMLRPCRequestHandler using TLS
| TLSXMLRPCServer Simple XML-RPC server using TLS

Variables | [hide private]
| __package__ = ``'``tlslite.integration``'``